@@ -1,3 +1,4 @@
+from math import floor
 from typing import Optional
 import numpy as np
 
@@ -203,19 +204,36 @@ class vimba_cam:
                 self.exposure_increment = self.cam.ExposureTimeIncrement.get()
                 self.exposure_unit = exposure.get_unit()
                 self.exposure_range = exposure.get_range()
-            set_value = self.exposure_increment * (
-                (value - self.exposure_range[0])//self.exposure_increment)\
+            floor_value = self.exposure_increment * np.floor(
+                (value - self.exposure_range[0])/self.exposure_increment)\
                 + self.exposure_range[0]
+            ceil_value = self.exposure_increment * np.ceil(
+                (value - self.exposure_range[0])/self.exposure_increment)\
+                + self.exposure_range[0]
+            set_value = 0
+            if np.abs(floor_value - value) < np.abs(ceil_value - value):
+                set_value = floor_value
+            else:
+                set_value = ceil_value
             set_value = max(
                 min(set_value, self.exposure_range[1]),
                 self.exposure_range[0])
             exposure.set(set_value)
-            self.exposure_current = set_value
+            self.get_exposure()
             return 1
         except Exception:
             print("Exposure Set ERROR")
             return 0
 
+    def set_black_level(self, value: float):
+        try:
+            blackLevel = self.cam.BlackLevel
+            blackLevel.set(value)
+            return 1
+        except Exception:
+            print("Black Level Set ERROR")
+            return 0
+
     def set_exposure_mode(self, value: str = 'Timed'):
         try:
             # with self.cam:
@@ -551,8 +569,23 @@ class vimba_cam:
             else:
                 return 0
         except Exception:
-            print("Pixel Format Set ERROR")
-            return 'NA'
+            pFormat = str(self.cam.get_pixel_format())
+            if '8' in pFormat:
+                self.pixel_size = 8
+                self.bytes_per_pixel = 1
+                return self.pixel_size
+            elif '12p' in pFormat:
+                print("Pixel Format Not supported.")
+                return 'NA'
+            elif '12' in pFormat:
+                self.pixel_size = 16
+                self.bytes_per_pixel = 2
+                return self.pixel_size
+            else:
+                print("Pixel Format Not supported.")
+                return 'NA'
+        finally:
+            self.set_black_level(5.0)
 
     def get_pixel_size(self):
         try:
@@ -565,6 +598,96 @@ class vimba_cam:
             print("Pixel Size Get ERROR")
             return 'NA'
 
+    def get_io_lines(self):
+        try:
+            lines = []
+            for line in self.cam.LineSelector.get_available_entries():
+                lines.append(str(line))
+            return lines
+        except Exception:
+            print("get_io_lines ERROR")
+            return None
+
+    def get_line_modes(self):
+        try:
+            modes = []
+            for mode in self.cam.LineMode.get_available_entries():
+                modes.append(str(mode))
+            return modes
+        except Exception:
+            print("get_line_modes ERROR")
+            return None
+
+    def get_line_sources(self):
+        try:
+            sources = []
+            for source in self.cam.LineSource.get_available_entries():
+                sources.append(str(source))
+            return sources
+        except Exception:
+            print("get_line_sources ERROR")
+            return None
+
+    def get_line_source(self):
+        try:
+            return str(self.cam.LineSource.get())
+        except Exception:
+            print("get_line_source ERROR")
+            return None
+
+    def get_line_mode(self):
+        try:
+            return str(self.cam.LineMode.get())
+        except Exception:
+            print("get_line_mode ERROR")
+            return None
+
+    def get_line_inverter(self):
+        try:
+            return self.cam.LineInverter.get()
+        except Exception:
+            print("get_line_inverter ERROR")
+            return None
+
+    def get_line_status(self):
+        try:
+            return self.cam.LineStatus.get()
+        except Exception:
+            print("get_line_status ERROR")
+            return None
+
+    def set_line_inverter(self, value: bool):
+        try:
+            self.cam.LineInverter.set(value)
+            return True
+        except Exception:
+            print("set_line_inverter ERROR")
+            return False
+
+    def set_line_source(self, value: str):
+        try:
+            self.cam.LineSource.set(value)
+            return True
+        except Exception:
+            print("set_line_source ERROR")
+            return False
+
+    def set_line_mode(self, value: str):
+        try:
+            self.cam.LineMode.set(value)
+            return True
+        except Exception:
+            print("set_line_mode ERROR")
+            return False
+
+    def select_io_line(self, value: str):
+        try:
+            self.cam.LineSelector.set(value)
+            return True
+        except Exception:
+            print("select_io_line ERROR")
+            return False
+
     def get_roi(self):
         try:
             # with self.cam:
@@ -632,8 +755,8 @@ class vimba_cam:
         return values[np.abs(values - value).argmin()]
 
 
-if __name__ == '__main__':
-    camera = vimba_cam('')
+# if __name__ == '__main__':
+    # camera = vimba_cam('')
 
     # with camera.vimba, camera.cam:
     #     camera.set_exposure(-1)
